"use client";
import { ChangeEvent, FormEvent, useEffect, useState } from "react";
import { addWine } from "../server/actions/addWine";
import { getProducers } from "../server/actions/allProducers";

interface Producer {
  id: string;
  name: string;
  createdAt: Date;
  country: string;
  region: string;
  email: string;
}

export default function CreateWine() {
  const [name, setName] = useState("");
  const [producer, setProducer] = useState("");
  const [allProducers, setAllProducers] = useState<Producer[]>([]);

  useEffect(() => {
    const fetchProducers = async () => {
      try {
        const producers = await getProducers();
        setAllProducers(producers);
      } catch (error) {
        console.error("Failed to fetch producers:", error);
      }
    };
    fetchProducers();
  }, []);

  const handleName = (event: ChangeEvent<HTMLInputElement>) => {
    setName(event.target.value);
  };
  const handleProducer = (event: ChangeEvent<HTMLSelectElement>) => {
    setProducer(event.target.value);
  };
  const handleAdd = async (event: FormEvent) => {
    event.preventDefault();
    addWine(producer, name);
    setName("");
  };
  return (
    <div>
      <input type="text" onChange={handleName} value={name} />
      <select name="producer" onSelect={handleProducer}>
        {allProducers.map((item) => (
          <option key={item.id} value={item.id}>
            {item.name}
          </option>
        ))}
      </select>
      <button onClick={handleAdd}>Submit wine</button>
    </div>
  );
}
